Home - rich-color-ext
Author: Max Ludden
Description: Extend Rich with CSS color names and 3-digit hex parsing

Skip to content

#

`rich-color-ext` extends the Rich library to parse 3-digit hex colors (`#09F`→`#0099FF`) and CSS color names (`rebeccapurple`→`#663399`). This project allows Rich users to write color names or short hex codes and have them correctly parsed into Rich Color instances.

## Key features

- Parse 3-digit hex colors like `#abc` → `#AABBCC`
- Parse CSS color names `rebeccapurple`, `mediumslateblue`
- Lightweight monkey-patch to Rich's `Color.parse` to add the above support.

For installation instructions, usage examples, packaging notes and more, see the sections linked from the navigation.

Next: Usage